@@ -20,35 +20,27 @@
 #include <unistd.h>
 
 #ifdef SE2PAR
-#  undef SE2PAR
-#endif
-
-#if IGRAPH_THREAD_SAFE
-#   define SE2PAR
-#endif
-
-#ifdef SE2PAR
-#  include <pthread.h>
+#include <pthread.h>
 #endif
 
 #include "se2_error_handling.h"
-#include "se2_neighborlist.h"
-#include "se2_seeding.h"
-#include "se2_random.h"
 #include "se2_modes.h"
+#include "se2_neighborlist.h"
+#include "se2_random.h"
 #include "se2_reweigh_graph.h"
+#include "se2_seeding.h"
 
 igraph_bool_t greeting_printed = false;
 igraph_error_t se2_thread_errorcode = IGRAPH_SUCCESS;
 pthread_mutex_t se2_error_mutex;
 
-#define SE2_SET_OPTION(opts, field, default) \
-    (opts->field) = (opts)->field ? (opts)->field : (default)
+#define SE2_SET_OPTION(opts, field, default)                                   \
+  (opts->field) = (opts)->field ? (opts)->field : (default)
 
-static igraph_error_t se2_core(se2_neighs const* graph,
-                               igraph_vector_int_list_t* partition_list,
+static igraph_error_t se2_core(se2_neighs const *graph,
+                               igraph_vector_int_list_t *partition_list,
                                igraph_integer_t const partition_offset,
-                               se2_options const* opts)
+                               se2_options const *opts)
 {
   se2_tracker tracker;
   se2_partition working_partition;
@@ -56,25 +48,23 @@ static igraph_error_t se2_core(se2_neighs const* graph,
   SE2_THREAD_CHECK(se2_tracker_init( &tracker, opts));
   IGRAPH_FINALLY(se2_tracker_destroy, &tracker);
 
-  igraph_vector_int_t* ic_store = &VECTOR(* partition_list)[partition_offset];
+  igraph_vector_int_t *ic_store = &VECTOR( *partition_list)[partition_offset];
   SE2_THREAD_CHECK(se2_partition_init( &working_partition, graph, ic_store));
   IGRAPH_FINALLY(se2_partition_destroy, &working_partition);
 
   igraph_integer_t partition_idx = partition_offset;
   for (igraph_integer_t time = 0; !se2_do_terminate( &tracker); time++) {
-    SE2_THREAD_CHECK(se2_mode_run_step(graph, &working_partition, &tracker,
-                                       time));
+    SE2_THREAD_CHECK(
+      se2_mode_run_step(graph, &working_partition, &tracker, time));
 #ifndef SE2PAR
     if ((time % 32) == 0) {
-      if (se2_check_user_interrupt()) {
-        SE2_THREAD_CHECK(IGRAPH_INTERRUPTED);
-      }
+      SE2_THREAD_CHECK(igraph_allow_interruption(NULL));
     }
 #endif
 
     if (se2_do_save_partition( &tracker)) {
-      SE2_THREAD_CHECK(
-        se2_partition_store( &working_partition, partition_list, partition_idx));
+      SE2_THREAD_CHECK(se2_partition_store( &working_partition, partition_list,
+                                            partition_idx));
       partition_idx++;
     }
   }
@@ -88,15 +78,15 @@ static igraph_error_t se2_core(se2_neighs const* graph,
 
 struct represent_parameters {
   igraph_integer_t tid;
-  se2_options* opts;
+  se2_options *opts;
   igraph_integer_t n_partitions;
-  igraph_vector_int_list_t* partition_store;
-  igraph_matrix_t* nmi_sum_accumulator;
+  igraph_vector_int_list_t *partition_store;
+  igraph_matrix_t *nmi_sum_accumulator;
 };
 
-static void* se2_thread_mrp(void* parameters)
+static void *se2_thread_mrp(void *parameters)
 {
-  struct represent_parameters* p = (struct represent_parameters*)parameters;
+  struct represent_parameters *p = (struct represent_parameters *)parameters;
   igraph_real_t nmi;
 
   igraph_integer_t n_threads = p->opts->max_threads;
@@ -104,11 +94,10 @@ static void* se2_thread_mrp(void* parameters)
     for (igraph_integer_t j = (i + 1); j < p->n_partitions; j++) {
       igraph_compare_communities(
         igraph_vector_int_list_get_ptr(p->partition_store, i),
-        igraph_vector_int_list_get_ptr(p->partition_store, j),
-        &nmi,
+        igraph_vector_int_list_get_ptr(p->partition_store, j), &nmi,
         IGRAPH_COMMCMP_NMI);
-      MATRIX(* p->nmi_sum_accumulator, i, p->tid) += nmi;
-      MATRIX(* p->nmi_sum_accumulator, j, p->tid) += nmi;
+      MATRIX( *p->nmi_sum_accumulator, i, p->tid) += nmi;
+      MATRIX( *p->nmi_sum_accumulator, j, p->tid) += nmi;
     }
   }
 
@@ -116,13 +105,12 @@ static void* se2_thread_mrp(void* parameters)
 }
 
 static igraph_error_t se2_most_representative_partition(
-  igraph_vector_int_list_t const* partition_store,
+  igraph_vector_int_list_t const *partition_store,
   igraph_integer_t const n_partitions,
-  igraph_vector_int_t* most_representative_partition,
-  se2_options const* opts,
+  igraph_vector_int_t *most_representative_partition, se2_options const *opts,
   igraph_integer_t const subcluster)
 {
-  igraph_vector_int_t* selected_partition;
+  igraph_vector_int_t *selected_partition;
   igraph_matrix_t nmi_sum_accumulator;
   igraph_vector_t nmi_sums;
   igraph_integer_t idx = 0;
@@ -143,15 +131,15 @@ static igraph_error_t se2_most_representative_partition(
 #endif
   for (igraph_integer_t tid = 0; tid < opts->max_threads; tid++) {
     args[tid].tid = tid;
-    args[tid].opts = (se2_options*)opts;
+    args[tid].opts = (se2_options *)opts;
     args[tid].n_partitions = n_partitions;
-    args[tid].partition_store = (igraph_vector_int_list_t*)partition_store;
+    args[tid].partition_store = (igraph_vector_int_list_t *)partition_store;
     args[tid].nmi_sum_accumulator = &nmi_sum_accumulator;
 
 #ifdef SE2PAR
-    pthread_create( &threads[tid], NULL, se2_thread_mrp, (void*) &args[tid]);
+    pthread_create( &threads[tid], NULL, se2_thread_mrp, (void *) &args[tid]);
 #else
-    se2_thread_mrp((void*) &args[tid]);
+    se2_thread_mrp((void *) &args[tid]);
 #endif
   }
 
@@ -166,8 +154,8 @@ static igraph_error_t se2_most_representative_partition(
 
   if (opts->verbose && (subcluster == 0)) {
     mean_nmi = igraph_matrix_sum( &nmi_sum_accumulator);
-    mean_nmi /= (n_partitions* (n_partitions - 1));
-    se2_printf("Mean of all NMIs is %0.5f.\n", mean_nmi);
+    mean_nmi /= (n_partitions *(n_partitions - 1));
+    SE2_PRINTF("Mean of all NMIs is %0.5f.\n", mean_nmi);
   }
 
   for (igraph_integer_t i = 0; i < n_partitions; i++) {
@@ -185,7 +173,7 @@ static igraph_error_t se2_most_representative_partition(
 
   igraph_integer_t n_nodes = igraph_vector_int_size(selected_partition);
   for (igraph_integer_t i = 0; i < n_nodes; i++) {
-    VECTOR(* most_representative_partition)[i] = VECTOR(* selected_partition)[i];
+    VECTOR( *most_representative_partition)[i] = VECTOR( *selected_partition)[i];
   }
 
   return IGRAPH_SUCCESS;
@@ -200,40 +188,41 @@ enum bootstrap_status {
 
 struct bootstrap_params {
   igraph_integer_t tid;
-  igraph_integer_t* run_i;
+  igraph_integer_t *run_i;
   igraph_integer_t n_nodes;
-  se2_neighs* graph;
+  se2_neighs *graph;
   igraph_integer_t subcluster_iter;
-  igraph_vector_int_list_t* partition_store;
-  se2_options* opts;
-  igraph_integer_t* status;
-  igraph_integer_t* unique_labels;
-  igraph_vector_int_t* memb;
+  igraph_vector_int_list_t *partition_store;
+  se2_options *opts;
+  igraph_integer_t *status;
+  igraph_integer_t *unique_labels;
+  igraph_vector_int_t *memb;
 #ifdef SE2PAR
-  pthread_mutex_t* status_mutex;
+  pthread_mutex_t *status_mutex;
 #endif
 };
 
-static void print_info(struct bootstrap_params const* p)
+static igraph_error_t print_info(struct bootstrap_params const *p)
 {
   if ((p->opts->verbose) && (!p->subcluster_iter)) {
     if (!greeting_printed) {
       greeting_printed = true;
-      se2_printf("Completed generating initial labels.\n"
-                 "Produced %"IGRAPH_PRId" seed labels, "
-                 "while goal was %"IGRAPH_PRId".\n\n"
+      SE2_PRINTF("Completed generating initial labels.\n"
+                 "Produced %" IGRAPH_PRId " seed labels, "
+                 "while goal was %" IGRAPH_PRId ".\n\n"
                  "Starting level 1 clustering",
                  *p->unique_labels, p->opts->target_clusters);
 
       if (p->opts->max_threads > 1) {
-        se2_printf("; independent runs might not be displayed in order - "
-                   "that is okay...\n");
+        SE2_PUTS("; independent runs might not be displayed in order - "
+                 "that is okay...");
       } else {
-        se2_printf("...\n");
+        SE2_PUTS("...");
       }
     }
 
-    se2_printf("Starting independent run #%"IGRAPH_PRId" of %"IGRAPH_PRId"\n",
+    SE2_PRINTF("Starting independent run #%" IGRAPH_PRId " of %" IGRAPH_PRId
+               "\n",
                *p->run_i + 1, p->opts->independent_runs);
   }
 #ifdef SE2PAR
@@ -245,19 +234,21 @@ static void print_info(struct bootstrap_params const* p)
 #ifdef SE2PAR
   pthread_mutex_unlock(p->status_mutex);
 #endif
+
+  return IGRAPH_SUCCESS;
 }
 
-static void* se2_thread_bootstrap(void* parameters)
+static void *se2_thread_bootstrap(void *parameters)
 {
-  struct bootstrap_params const* p = (struct bootstrap_params*)parameters;
+  struct bootstrap_params const *p = (struct bootstrap_params *)parameters;
 
   igraph_integer_t const n_threads = p->opts->max_threads;
   igraph_integer_t const independent_runs = p->opts->independent_runs;
   for (igraph_integer_t run_i = p->tid; run_i < independent_runs;
        run_i += n_threads) {
     *p->run_i = run_i;
-    igraph_rng_t rng, * old_rng;
-    igraph_integer_t partition_offset = run_i* p->opts->target_partitions;
+    igraph_rng_t rng, *old_rng;
+    igraph_integer_t partition_offset = run_i *p->opts->target_partitions;
     igraph_vector_int_t ic_store;
 
     old_rng = se2_rng_init( &rng, run_i + p->opts->random_seed);
@@ -299,7 +290,7 @@ static void* se2_thread_bootstrap(void* parameters)
       .tv_nsec = 5000000, // 5ms
     };
     // Wait for print.
-    while ((p->opts->verbose) && (* p->status == SE2_STATUS_STARTED)) {
+    while ((p->opts->verbose) && ( *p->status == SE2_STATUS_STARTED)) {
       nanosleep( &pause, NULL);
     }
 #endif
@@ -321,13 +312,13 @@ static void* se2_thread_bootstrap(void* parameters)
 // Structure to allow destroying all mutexes with a single destroyer to reduce
 // load on the igraph finally stack.
 struct se2_pthread_mutex_array {
-  pthread_mutex_t* array;
+  pthread_mutex_t *array;
   igraph_integer_t n;
 };
 
 #ifdef SE2PAR
 void se2_pthread_mutex_array_destroy(
-  struct se2_pthread_mutex_array* mutex_array)
+  struct se2_pthread_mutex_array *mutex_array)
 {
   for (igraph_integer_t i = 0; i < mutex_array->n; i++) {
     pthread_mutex_destroy( &(mutex_array->array[i]));
@@ -335,23 +326,23 @@ void se2_pthread_mutex_array_destroy(
 }
 #endif
 
-static igraph_error_t se2_bootstrap(se2_neighs const* graph,
+static igraph_error_t se2_bootstrap(se2_neighs const *graph,
                                     igraph_integer_t const subcluster_iter,
-                                    se2_options const* opts,
-                                    igraph_vector_int_t* memb)
+                                    se2_options const *opts,
+                                    igraph_vector_int_t *memb)
 {
   se2_thread_errorcode = IGRAPH_SUCCESS;
 
   igraph_integer_t n_nodes = se2_vcount(graph);
-  igraph_integer_t n_partitions = opts->target_partitions*
-                                  opts->independent_runs;
+  igraph_integer_t n_partitions =
+    opts->target_partitions *opts->independent_runs;
   igraph_vector_int_list_t partition_store;
 
   IGRAPH_CHECK(igraph_vector_int_list_init( &partition_store, n_partitions));
   IGRAPH_FINALLY(igraph_vector_int_list_destroy, &partition_store);
 
   if ((opts->verbose) && (!subcluster_iter) && (opts->multicommunity > 1)) {
-    se2_puts("Attempting overlapping clustering.");
+    SE2_PUTS("Attempting overlapping clustering.");
   }
 
   igraph_vector_int_t thread_run;
@@ -370,9 +361,8 @@ static igraph_error_t se2_bootstrap(se2_neighs const* graph,
 #ifdef SE2PAR
   pthread_t threads[opts->max_threads];
   pthread_mutex_t status_mutex[opts->max_threads];
-  struct se2_pthread_mutex_array status_mutex_holder = {
-    .array = status_mutex,
-    .n = opts->max_threads
+  struct se2_pthread_mutex_array status_mutex_holder = {.array = status_mutex,
+           .n = opts->max_threads
   };
   for (igraph_integer_t i = 0; i < opts->max_threads; i++) {
     pthread_mutex_init(status_mutex + i, NULL);
@@ -388,10 +378,10 @@ static igraph_error_t se2_bootstrap(se2_neighs const* graph,
   for (igraph_integer_t tid = 0; tid < opts->max_threads; tid++) {
     args[tid].tid = tid;
     args[tid].n_nodes = n_nodes;
-    args[tid].graph = (se2_neighs*)graph;
+    args[tid].graph = (se2_neighs *)graph;
     args[tid].subcluster_iter = subcluster_iter;
     args[tid].partition_store = &partition_store;
-    args[tid].opts = (se2_options*)opts;
+    args[tid].opts = (se2_options *)opts;
     args[tid].run_i = &(VECTOR(thread_run)[tid]);
     args[tid].status = &(VECTOR(thread_status)[tid]);
     args[tid].unique_labels = &(VECTOR(unique_labels)[tid]);
@@ -401,9 +391,9 @@ static igraph_error_t se2_bootstrap(se2_neighs const* graph,
 
 #ifdef SE2PAR
     pthread_create( &threads[tid], NULL, se2_thread_bootstrap,
-                    (void*) &args[tid]);
+                    (void *) &args[tid]);
 #else
-    se2_thread_bootstrap((void*) &args[tid]);
+    se2_thread_bootstrap((void *) &args[tid]);
 #endif
   }
 
@@ -415,7 +405,7 @@ static igraph_error_t se2_bootstrap(se2_neighs const* graph,
 
   // Perform user interrupt check on main thread.
   while (igraph_vector_int_sum( &thread_status) !=
-         (SE2_STATUS_FINISHED* opts->max_threads)) {
+         (SE2_STATUS_FINISHED *opts->max_threads)) {
     nanosleep( &pause, NULL);
 
     for (igraph_integer_t i = 0; i < opts->max_threads; i++) {
@@ -424,7 +414,7 @@ static igraph_error_t se2_bootstrap(se2_neighs const* graph,
       }
     }
 
-    if (se2_check_user_interrupt()) {
+    if (igraph_allow_interruption(NULL) != IGRAPH_SUCCESS) {
       pthread_mutex_lock( &se2_error_mutex);
       se2_thread_errorcode = IGRAPH_INTERRUPTED;
       pthread_mutex_unlock( &se2_error_mutex);
@@ -453,12 +443,13 @@ static igraph_error_t se2_bootstrap(se2_neighs const* graph,
   IGRAPH_FINALLY_CLEAN(3);
 
   if ((opts->verbose) && (!subcluster_iter)) {
-    se2_printf("\nGenerated %"IGRAPH_PRId" partitions at level 1.\n",
+    SE2_PRINTF("\nGenerated %" IGRAPH_PRId " partitions at level 1.\n",
                n_partitions);
   }
 
   IGRAPH_CHECK(se2_most_representative_partition( &partition_store,
-               n_partitions, memb, opts, subcluster_iter));
+               n_partitions,
+               memb, opts, subcluster_iter));
 
   igraph_vector_int_list_destroy( &partition_store);
   IGRAPH_FINALLY_CLEAN(1);
@@ -466,7 +457,7 @@ static igraph_error_t se2_bootstrap(se2_neighs const* graph,
   return IGRAPH_SUCCESS;
 }
 
-static igraph_integer_t default_target_clusters(se2_neighs const* graph)
+static igraph_integer_t default_target_clusters(se2_neighs const *graph)
 {
   igraph_integer_t const n_nodes = se2_vcount(graph);
   if (n_nodes < 10) {
@@ -489,8 +480,7 @@ static igraph_integer_t default_max_threads(igraph_integer_t const runs)
   return n_threads;
 }
 
-static void se2_set_defaults(se2_neighs const* graph,
-                             se2_options* opts)
+static void se2_set_defaults(se2_neighs const *graph, se2_options *opts)
 {
   SE2_SET_OPTION(opts, independent_runs, 10);
   SE2_SET_OPTION(opts, subcluster, 1);
@@ -506,22 +496,22 @@ static void se2_set_defaults(se2_neighs const* graph,
   SE2_SET_OPTION(opts, verbose, false);
 }
 
-static igraph_error_t se2_collect_community_members(
-  igraph_vector_int_t const* memb,
-  igraph_vector_int_t* idx,
-  igraph_integer_t const comm)
+static igraph_error_t se2_collect_community_members(igraph_vector_int_t const
+    *memb,
+    igraph_vector_int_t *idx,
+    igraph_integer_t const comm)
 {
   igraph_integer_t n_memb = 0;
   for (igraph_integer_t i = 0; i < igraph_vector_int_size(memb); i++) {
-    n_memb += VECTOR(* memb)[i] == comm;
+    n_memb += VECTOR( *memb)[i] == comm;
   }
 
   IGRAPH_CHECK(igraph_vector_int_init(idx, n_memb));
   IGRAPH_FINALLY(igraph_vector_int_destroy, idx);
   igraph_integer_t count = 0;
   for (igraph_integer_t i = 0; i < igraph_vector_int_size(memb); i++) {
-    if (VECTOR(* memb)[i] == comm) {
-      VECTOR(* idx)[count] = i;
+    if (VECTOR( *memb)[i] == comm) {
+      VECTOR( *idx)[count] = i;
       count++;
     }
   }
@@ -530,34 +520,33 @@ static igraph_error_t se2_collect_community_members(
   return IGRAPH_SUCCESS;
 }
 
-static igraph_error_t se2_subgraph_from_community(
-  se2_neighs const* origin,
-  se2_neighs* subgraph,
-  igraph_vector_int_t const* members)
+static igraph_error_t se2_subgraph_from_community(se2_neighs const *origin,
+    se2_neighs *subgraph,
+    igraph_vector_int_t const *members)
 {
   igraph_integer_t const n_membs = igraph_vector_int_size(members);
   subgraph->n_nodes = n_membs;
 
-  subgraph->neigh_list = igraph_malloc(sizeof(* subgraph->neigh_list));
+  subgraph->neigh_list = igraph_malloc(sizeof( *subgraph->neigh_list));
   IGRAPH_CHECK_OOM(subgraph->neigh_list, "");
   IGRAPH_FINALLY(igraph_free, subgraph->neigh_list);
   IGRAPH_CHECK(igraph_vector_int_list_init(subgraph->neigh_list, n_membs));
   IGRAPH_FINALLY(igraph_vector_int_list_destroy, subgraph->neigh_list);
 
-  subgraph->sizes = igraph_malloc(sizeof(* subgraph->sizes));
+  subgraph->sizes = igraph_malloc(sizeof( *subgraph->sizes));
   IGRAPH_CHECK_OOM(subgraph->sizes, "");
   IGRAPH_FINALLY(igraph_free, subgraph->sizes);
   IGRAPH_CHECK(igraph_vector_int_init(subgraph->sizes, n_membs));
   IGRAPH_FINALLY(igraph_vector_int_destroy, subgraph->sizes);
 
-  subgraph->kin = igraph_malloc(sizeof(* subgraph->kin));
+  subgraph->kin = igraph_malloc(sizeof( *subgraph->kin));
   IGRAPH_CHECK_OOM(subgraph->kin, "");
   IGRAPH_FINALLY(igraph_free, subgraph->kin);
   IGRAPH_CHECK(igraph_vector_init(subgraph->kin, n_membs));
   IGRAPH_FINALLY(igraph_vector_destroy, subgraph->kin);
 
-  if (HASWEIGHTS(* origin)) {
-    subgraph->weights = igraph_malloc(sizeof(* subgraph->weights));
+  if (HASWEIGHTS( *origin)) {
+    subgraph->weights = igraph_malloc(sizeof( *subgraph->weights));
     IGRAPH_CHECK_OOM(subgraph->weights, "");
     IGRAPH_FINALLY(igraph_free, subgraph->weights);
     IGRAPH_CHECK(igraph_vector_list_init(subgraph->weights, n_membs));
@@ -567,46 +556,47 @@ static igraph_error_t se2_subgraph_from_community(
   }
 
   for (igraph_integer_t i = 0; i < n_membs; i++) {
-    igraph_integer_t node_id = VECTOR(* members)[i];
-    igraph_vector_int_t* neighs = &NEIGHBORS(* origin, node_id);
-    igraph_vector_int_t* new_neighs = &NEIGHBORS(* subgraph, i);
-    igraph_integer_t const n_neighs = N_NEIGHBORS(* origin, node_id);
-    igraph_vector_t* w = HASWEIGHTS(* subgraph) ?
-                         &WEIGHTS_IN(* subgraph, i) : NULL;
+    igraph_integer_t node_id = VECTOR( *members)[i];
+    igraph_vector_int_t *neighs = &NEIGHBORS( *origin, node_id);
+    igraph_vector_int_t *new_neighs = &NEIGHBORS( *subgraph, i);
+    igraph_integer_t const n_neighs = N_NEIGHBORS( *origin, node_id);
+    igraph_vector_t *w =
+      HASWEIGHTS( *subgraph) ? &WEIGHTS_IN( *subgraph, i) : NULL;
 
     IGRAPH_CHECK(igraph_vector_int_resize(new_neighs, n_neighs));
-    if (HASWEIGHTS(* subgraph)) {
+    if (HASWEIGHTS( *subgraph)) {
       IGRAPH_CHECK(igraph_vector_resize(w, n_neighs));
     }
 
     igraph_integer_t count = 0;
     igraph_integer_t pos;
     for (igraph_integer_t j = 0; j < n_neighs; j++) {
-      if (igraph_vector_int_search(members, 0, VECTOR(* neighs)[j], &pos)) {
-        VECTOR(* new_neighs)[count] = pos;
-        if (HASWEIGHTS(* subgraph)) {
-          VECTOR(* w)[count] = WEIGHT(* origin, node_id, j);
+      if (igraph_vector_int_search(members, 0, VECTOR( *neighs)[j], &pos)) {
+        VECTOR( *new_neighs)[count] = pos;
+        if (HASWEIGHTS( *subgraph)) {
+          VECTOR( *w)[count] = WEIGHT( *origin, node_id, j);
         }
         count++;
       }
     }
 
-    VECTOR(* subgraph->sizes)[i] = count;
+    VECTOR( *subgraph->sizes)[i] = count;
     IGRAPH_CHECK(igraph_vector_int_resize(new_neighs, count));
-    if (HASWEIGHTS(* subgraph)) {
+    if (HASWEIGHTS( *subgraph)) {
       IGRAPH_CHECK(igraph_vector_resize(w, count));
     }
   }
 
   for (igraph_integer_t i = 0; i < n_membs; i++) {
-    for (igraph_integer_t j = 0; j < N_NEIGHBORS(* subgraph, i); j++) {
-      VECTOR(* subgraph->kin)[NEIGHBOR(* subgraph, i, j)] +=
-        HASWEIGHTS(* subgraph) ? WEIGHT(* subgraph, i, j) : 1;
+    for (igraph_integer_t j = 0; j < N_NEIGHBORS( *subgraph, i); j++) {
+      VECTOR( *subgraph->kin)
+      [NEIGHBOR( *subgraph, i, j)] +=
+        HASWEIGHTS( *subgraph) ? WEIGHT( *subgraph, i, j) : 1;
     }
   }
   subgraph->total_weight = igraph_vector_sum(subgraph->kin);
 
-  if (HASWEIGHTS(* subgraph)) {
+  if (HASWEIGHTS( *subgraph)) {
     IGRAPH_FINALLY_CLEAN(2);
   }
   IGRAPH_FINALLY_CLEAN(6);
@@ -617,12 +607,12 @@ static igraph_error_t se2_subgraph_from_community(
 /* For hierarchical clustering, each community from the previous level gets
 clustered. Each of these clusters gets a "private scope" set of labels starting
 at 0. These must be relabeled to a global scope. */
-static igraph_error_t se2_relabel_hierarchical_communities(
-  igraph_vector_int_t const* prev_membs,
-  igraph_vector_int_t* level_membs)
+static igraph_error_t
+se2_relabel_hierarchical_communities(igraph_vector_int_t const *prev_membs,
+                                     igraph_vector_int_t *level_membs)
 {
-  igraph_integer_t const n_comms = igraph_vector_int_max(prev_membs) -
-                                   igraph_vector_int_min(prev_membs);
+  igraph_integer_t const n_comms =
+    igraph_vector_int_max(prev_membs) - igraph_vector_int_min(prev_membs);
 
   igraph_integer_t prev_max = 0;
   igraph_integer_t curr_max = 0;
@@ -632,9 +622,10 @@ static igraph_error_t se2_relabel_hierarchical_communities(
     IGRAPH_FINALLY(igraph_vector_int_destroy, &member_ids);
 
     for (igraph_integer_t j = 0; j < igraph_vector_int_size( &member_ids); j++) {
-      igraph_integer_t local_label = VECTOR(* level_membs)[VECTOR(member_ids)[j]];
+      igraph_integer_t local_label =
+        VECTOR( *level_membs)[VECTOR(member_ids)[j]];
 
-      VECTOR(* level_membs)[VECTOR(member_ids)[j]] += prev_max;
+      VECTOR( *level_membs)[VECTOR(member_ids)[j]] += prev_max;
       if ((local_label + prev_max) > curr_max) {
         curr_max = local_label + prev_max;
       }
@@ -658,8 +649,8 @@ static igraph_error_t se2_relabel_hierarchical_communities(
 
 \return Error code:
 */
-igraph_error_t speak_easy_2(se2_neighs* graph, se2_options* opts,
-                            igraph_matrix_int_t* memb)
+igraph_error_t speak_easy_2(se2_neighs *graph, se2_options *opts,
+                            igraph_matrix_int_t *memb)
 {
   /* In high level interfaces, the value of file-scope variables are held onto
      for the duration of the session. If SE2 is called multiple times within a
@@ -681,10 +672,10 @@ igraph_error_t speak_easy_2(se2_neighs* graph, se2_options* opts,
 
   if (opts->verbose) {
     igraph_bool_t isweighted = false;
-    if (HASWEIGHTS(* graph)) {
+    if (HASWEIGHTS( *graph)) {
       for (igraph_integer_t i = 0; i < se2_vcount(graph); i++) {
-        for (igraph_integer_t j = 0; j < N_NEIGHBORS(* graph, i); j++) {
-          if (WEIGHT(* graph, i, j) != 1) {
+        for (igraph_integer_t j = 0; j < N_NEIGHBORS( *graph, i); j++) {
+          if (WEIGHT( *graph, i, j) != 1) {
             isweighted = true;
             break;
           }
@@ -700,14 +691,14 @@ igraph_error_t speak_easy_2(se2_neighs* graph, se2_options* opts,
     igraph_real_t edge_density =
       (igraph_real_t)(se2_ecount(graph) - se2_vcount(graph)) /
       (possible_edges - se2_vcount(graph));
-    se2_printf("Approximate edge density is %g.\n"
+    SE2_PRINTF("Approximate edge density is %g.\n"
                "Input type treated as %s.\n\n"
                "Calling main routine at level 1.\n",
                edge_density, isweighted ? "weighted" : "unweighted");
   }
 
-  IGRAPH_CHECK(igraph_matrix_int_init(memb, opts->subcluster,
-                                      se2_vcount(graph)));
+  IGRAPH_CHECK(
+    igraph_matrix_int_init(memb, opts->subcluster, se2_vcount(graph)));
   IGRAPH_FINALLY(igraph_matrix_int_destroy, memb);
 
   igraph_vector_int_t level_memb;
@@ -719,21 +710,21 @@ igraph_error_t speak_easy_2(se2_neighs* graph, se2_options* opts,
 
   for (igraph_integer_t level = 1; level < opts->subcluster; level++) {
     if (opts->verbose) {
-      se2_printf("\nSubclustering at level %"IGRAPH_PRId".\n", level + 1);
+      SE2_PRINTF("\nSubclustering at level %" IGRAPH_PRId ".\n", level + 1);
     }
 
     igraph_vector_int_t prev_memb;
-    IGRAPH_CHECK(igraph_vector_int_init( &prev_memb,
-                                         igraph_matrix_int_ncol(memb)));
+    IGRAPH_CHECK(
+      igraph_vector_int_init( &prev_memb, igraph_matrix_int_ncol(memb)));
     IGRAPH_FINALLY(igraph_vector_int_destroy, &prev_memb);
     IGRAPH_CHECK(igraph_matrix_int_get_row(memb, &prev_memb, level - 1));
 
-    igraph_integer_t const n_comms = igraph_vector_int_max( &prev_memb) -
-                                     igraph_vector_int_min( &prev_memb);
+    igraph_integer_t const n_comms =
+      igraph_vector_int_max( &prev_memb) - igraph_vector_int_min( &prev_memb);
     for (igraph_integer_t comm = 0; comm < n_comms; comm++) {
       igraph_vector_int_t member_ids;
-      IGRAPH_CHECK(se2_collect_community_members(
-                     &prev_memb, &member_ids, comm));
+      IGRAPH_CHECK(
+        se2_collect_community_members( &prev_memb, &member_ids, comm));
       IGRAPH_FINALLY(igraph_vector_int_destroy, &member_ids);
       igraph_integer_t const n_membs = igraph_vector_int_size( &member_ids);
 
@@ -780,7 +771,7 @@ igraph_error_t speak_easy_2(se2_neighs* graph, se2_options* opts,
   IGRAPH_FINALLY_CLEAN(1);
 
   if (opts->verbose) {
-    se2_printf("\n");
+    SE2_PRINT("\n");
   }
 
   IGRAPH_FINALLY_CLEAN(1); // memb
