@@ -19,26 +19,24 @@
 #include <speak_easy_2.h>
 
 static void se2_insert_sim(igraph_real_t const s,
-                           igraph_vector_t* similarities,
+                           igraph_vector_t *similarities,
                            igraph_integer_t const col,
                            igraph_integer_t const other_col,
-                           igraph_integer_t* edges,
-                           igraph_integer_t const k)
+                           igraph_integer_t *edges, igraph_integer_t const k)
 {
   /* Edges is a vector of edge pairs for the given column. The first edge of
      each pair is col (constant) the second is other_col. As such only the
      second member of each pair ever needs to be modified. */
   if (k == 1) {
-    VECTOR(* similarities)[0] = s;
+    VECTOR(*similarities)[0] = s;
     edges[1] = other_col;
   }
 
   igraph_integer_t bounds[2] = {0, k};
   igraph_integer_t pos = (k - 1) / 2;
-  while (!((pos == (k - 1)) ||
-           ((s >= VECTOR(* similarities)[pos]) &&
-            (s < VECTOR(* similarities)[pos + 1])))) {
-    if (s < VECTOR(* similarities)[pos]) {
+  while (!((pos == (k - 1)) || ((s >= VECTOR(*similarities)[pos]) &&
+                                (s < VECTOR(*similarities)[pos + 1])))) {
+    if (s < VECTOR(*similarities)[pos]) {
       bounds[1] = pos;
     } else {
       bounds[0] = pos;
@@ -47,38 +45,39 @@ static void se2_insert_sim(igraph_real_t const s,
   }
 
   for (int i = 0; i < pos; i++) {
-    VECTOR(* similarities)[i] = VECTOR(* similarities)[i + 1];
+    VECTOR(*similarities)[i] = VECTOR(*similarities)[i + 1];
     edges[(2 * i) + 1] = edges[(2 * (i + 1)) + 1];
   }
-  VECTOR(* similarities)[pos] = s;
+  VECTOR(*similarities)[pos] = s;
   edges[(2 * pos) + 1] = other_col;
 }
 
 static igraph_real_t se2_euclidean_dist(igraph_integer_t const i,
                                         igraph_integer_t const j,
-                                        igraph_matrix_t* const mat)
+                                        igraph_matrix_t *const mat)
 {
   igraph_integer_t const n_rows = igraph_matrix_nrow(mat);
-  igraph_real_t* col_i = igraph_matrix_get_ptr(mat, 0, i);
-  igraph_real_t* col_j = igraph_matrix_get_ptr(mat, 0, j);
+  igraph_real_t *col_i = igraph_matrix_get_ptr(mat, 0, i);
+  igraph_real_t *col_j = igraph_matrix_get_ptr(mat, 0, j);
   igraph_real_t out = 0;
   for (igraph_integer_t k = 0; k < n_rows; k++) {
     double el = col_i[k] - col_j[k];
-    out += el* el;
+    out += el *el;
   }
 
   return sqrt(out);
 }
 
-static igraph_error_t se2_closest_k(
-  igraph_integer_t const col, igraph_integer_t const k,
-  igraph_matrix_t* const mat, igraph_vector_int_t* edges,
-  igraph_vector_t* weights)
+static igraph_error_t se2_closest_k(igraph_integer_t const col,
+                                    igraph_integer_t const k,
+                                    igraph_matrix_t *const mat,
+                                    igraph_vector_int_t *edges,
+                                    igraph_vector_t *weights)
 {
   igraph_vector_t similarities;
   igraph_integer_t n_cols = igraph_matrix_ncol(mat);
 
-  IGRAPH_CHECK(igraph_vector_init( &similarities, k));
+  IGRAPH_CHECK(igraph_vector_init(&similarities, k));
   IGRAPH_FINALLY(igraph_vector_destroy, &similarities);
 
   for (igraph_integer_t i = 0; i < n_cols; i++) {
@@ -88,30 +87,30 @@ static igraph_error_t se2_closest_k(
 
     igraph_real_t s = 1 / se2_euclidean_dist(col, i, mat);
     if (s > VECTOR(similarities)[0]) {
-      igraph_integer_t* col_edges = VECTOR(* edges) + (2 * col* k);
+      igraph_integer_t *col_edges = VECTOR(*edges) + (2 * col *k);
       se2_insert_sim(s, &similarities, col, i, col_edges, k);
     }
   }
 
   if (weights) {
     for (igraph_integer_t i = 0; i < k; i++) {
-      VECTOR(* weights)[(col* k) + i] = VECTOR(similarities)[i];
+      VECTOR(*weights)[(col *k) + i] = VECTOR(similarities)[i];
     }
   }
 
-  igraph_vector_destroy( &similarities);
+  igraph_vector_destroy(&similarities);
   IGRAPH_FINALLY_CLEAN(1);
 
   return IGRAPH_SUCCESS;
 }
 
-static void se2_knn_fill_edges(igraph_vector_int_t* edges,
+static void se2_knn_fill_edges(igraph_vector_int_t *edges,
                                igraph_integer_t const k,
                                igraph_integer_t const n_cols)
 {
   for (igraph_integer_t i = 0; i < n_cols; i++) {
     for (igraph_integer_t j = 0; j < k; j++) {
-      VECTOR(* edges)[2 * (i* k + j)] = i;
+      VECTOR(*edges)[2 * (i *k + j)] = i;
     }
   }
 }
@@ -128,48 +127,51 @@ static void se2_knn_fill_edges(igraph_vector_int_t* edges,
 \return Error code:
          \c IGRAPH_EINVAL: Invalid value for k.
  */
-igraph_error_t se2_knn_graph(igraph_matrix_t* const mat,
-                             igraph_integer_t const k,
-                             igraph_t* res, igraph_vector_t* weights)
+igraph_error_t se2_knn_graph(igraph_matrix_t *const mat,
+                             igraph_integer_t const k, igraph_t *res,
+                             igraph_vector_t *weights)
 {
   igraph_integer_t const n_cols = igraph_matrix_ncol(mat);
-  igraph_integer_t const n_edges = k* n_cols;
+  igraph_integer_t const n_edges = k *n_cols;
   igraph_vector_int_t edges;
 
   IGRAPH_CHECK(igraph_empty(res, n_cols, IGRAPH_DIRECTED));
   IGRAPH_FINALLY(igraph_destroy, res);
+
   if (weights) {
     IGRAPH_CHECK(igraph_vector_init(weights, n_edges));
     IGRAPH_FINALLY(igraph_vector_destroy, weights);
   }
 
-  IGRAPH_CHECK(igraph_vector_int_init( &edges, 2 * n_edges));
+  IGRAPH_CHECK(igraph_vector_int_init(&edges, 2 * n_edges));
   IGRAPH_FINALLY(igraph_vector_int_destroy, &edges);
-  se2_knn_fill_edges( &edges, k, n_cols);
+  se2_knn_fill_edges(&edges, k, n_cols);
 
   if (k < 1) {
-    IGRAPH_ERRORF("The k must be at least 1 but got %"IGRAPH_PRId".\n",
+    IGRAPH_ERRORF("The k must be at least 1 but got %" IGRAPH_PRId ".\n",
                   IGRAPH_EINVAL, k);
   }
 
   if (k >= (n_cols - 1)) {
     IGRAPH_ERRORF("The k must be less than the number of columns, "
-                  "got k = %"IGRAPH_PRId" with only %"IGRAPH_PRId" columns.\n",
+                  "got k = %" IGRAPH_PRId " with only %" IGRAPH_PRId
+                  " columns.\n",
                   IGRAPH_EINVAL, k, n_cols);
   }
 
-  if (weights) {
-    IGRAPH_CHECK(igraph_vector_resize(weights, n_edges));
-  }
-
   for (igraph_integer_t i = 0; i < n_cols; i++) {
     IGRAPH_CHECK(se2_closest_k(i, k, mat, &edges, weights));
   }
 
   IGRAPH_CHECK(igraph_add_edges(res, &edges, NULL));
-  igraph_vector_int_destroy( &edges);
+  igraph_vector_int_destroy(&edges);
+  IGRAPH_FINALLY_CLEAN(1);
 
-  IGRAPH_FINALLY_CLEAN(3);
+  if (weights) {
+    IGRAPH_FINALLY_CLEAN(1);
+  }
+
+  IGRAPH_FINALLY_CLEAN(1);
 
   return IGRAPH_SUCCESS;
 }
