@@ -16,17 +16,17 @@
  * with SpeakEasy 2. If not, see <https://www.gnu.org/licenses/>.
  */
 
-#include "se2_interface.h"
 #include "se2_partitions.h"
-#include "se2_random.h"
 #include "se2_error_handling.h"
+#include "se2_interface.h"
 #include "se2_neighborlist.h"
+#include "se2_random.h"
 
 #define MAX(a, b) (a) > (b) ? (a) : (b)
 
-static igraph_integer_t se2_count_labels(
-  igraph_vector_int_t const* membership,
-  igraph_vector_int_t* community_sizes)
+static igraph_integer_t se2_count_labels(igraph_vector_int_t const
+    *membership,
+    igraph_vector_int_t *community_sizes)
 {
   igraph_integer_t max_label = igraph_vector_int_max(membership);
   igraph_integer_t n_labels = 0;
@@ -37,21 +37,19 @@ static igraph_integer_t se2_count_labels(
 
   igraph_vector_int_null(community_sizes);
   for (igraph_integer_t i = 0; i < n_nodes; i++) {
-    VECTOR(* community_sizes)[VECTOR(* membership)[i]]++;
+    VECTOR(*community_sizes)[VECTOR(*membership)[i]]++;
   }
 
   for (igraph_integer_t i = 0; i <= max_label; i++) {
-    n_labels += VECTOR(* community_sizes)[i] > 0;
+    n_labels += VECTOR(*community_sizes)[i] > 0;
   }
 
   return n_labels;
 }
 
 static igraph_error_t se2_count_local_labels(
-  se2_neighs const* graph,
-  igraph_vector_int_t const* initial_labels,
-  igraph_integer_t const max_label,
-  igraph_matrix_t* labels_heard)
+  se2_neighs const *graph, igraph_vector_int_t const *initial_labels,
+  igraph_integer_t const max_label, igraph_matrix_t *labels_heard)
 {
   igraph_integer_t const n_nodes = igraph_vector_int_size(initial_labels);
   igraph_integer_t const n_labels = max_label + 1;
@@ -62,21 +60,20 @@ static igraph_error_t se2_count_local_labels(
   }
 
   for (igraph_integer_t node_id = 0; node_id < n_nodes; node_id++) {
-    igraph_integer_t const label = VECTOR(* initial_labels)[node_id];
-    for (igraph_integer_t j = 0; j < N_NEIGHBORS(* graph, node_id); j++) {
-      MATRIX(* labels_heard, NEIGHBOR(* graph, node_id, j), label) +=
-        WEIGHT(* graph, node_id, j);
+    igraph_integer_t const label = VECTOR(*initial_labels)[node_id];
+    for (igraph_integer_t j = 0; j < N_NEIGHBORS(*graph, node_id); j++) {
+      MATRIX(*labels_heard, NEIGHBOR(*graph, node_id, j), label) +=
+        WEIGHT(*graph, node_id, j);
     }
   }
 
   return IGRAPH_SUCCESS;
 }
 
-static igraph_error_t se2_count_global_labels(
-  se2_neighs const* graph,
-  igraph_integer_t const max_label,
-  igraph_matrix_t const* local_labels_heard,
-  igraph_vector_t* global_labels_heard)
+static igraph_error_t se2_count_global_labels(se2_neighs const *graph,
+    igraph_integer_t const max_label,
+    igraph_matrix_t const *local_labels_heard,
+    igraph_vector_t *global_labels_heard)
 {
   igraph_integer_t const n_labels = max_label + 1;
 
@@ -84,42 +81,42 @@ static igraph_error_t se2_count_global_labels(
     SE2_THREAD_CHECK(igraph_vector_resize(global_labels_heard, n_labels));
   }
 
-  SE2_THREAD_CHECK(igraph_matrix_colsum(local_labels_heard,
-                                        global_labels_heard));
+  SE2_THREAD_CHECK(
+    igraph_matrix_colsum(local_labels_heard, global_labels_heard));
 
   return IGRAPH_SUCCESS;
 }
 
-igraph_error_t se2_partition_init(se2_partition* partition,
-                                  se2_neighs const* graph,
-                                  igraph_vector_int_t const* initial_labels)
+igraph_error_t se2_partition_init(se2_partition *partition,
+                                  se2_neighs const *graph,
+                                  igraph_vector_int_t const *initial_labels)
 {
   igraph_integer_t const n_nodes = igraph_vector_int_size(initial_labels);
 
-  igraph_vector_int_t* reference = igraph_malloc(sizeof(* reference));
+  igraph_vector_int_t *reference = igraph_malloc(sizeof(*reference));
   SE2_THREAD_CHECK_OOM(reference);
   IGRAPH_FINALLY(igraph_free, reference);
 
-  igraph_vector_int_t* stage = igraph_malloc(sizeof(* stage));
+  igraph_vector_int_t *stage = igraph_malloc(sizeof(*stage));
   SE2_THREAD_CHECK_OOM(stage);
   IGRAPH_FINALLY(igraph_free, stage);
 
-  igraph_vector_t* specificity = igraph_malloc(sizeof(* specificity));
+  igraph_vector_t *specificity = igraph_malloc(sizeof(*specificity));
   SE2_THREAD_CHECK_OOM(specificity);
   IGRAPH_FINALLY(igraph_free, specificity);
 
-  igraph_vector_int_t* community_sizes =
-    igraph_malloc(sizeof(* community_sizes));
+  igraph_vector_int_t *community_sizes =
+    igraph_malloc(sizeof(*community_sizes));
   SE2_THREAD_CHECK_OOM(community_sizes);
   IGRAPH_FINALLY(igraph_free, community_sizes);
 
-  igraph_matrix_t* local_labels_heard =
-    igraph_malloc(sizeof(* local_labels_heard));
+  igraph_matrix_t *local_labels_heard =
+    igraph_malloc(sizeof(*local_labels_heard));
   SE2_THREAD_CHECK_OOM(local_labels_heard);
   IGRAPH_FINALLY(igraph_free, local_labels_heard);
 
-  igraph_vector_t* global_labels_heard =
-    igraph_malloc(sizeof(* global_labels_heard));
+  igraph_vector_t *global_labels_heard =
+    igraph_malloc(sizeof(*global_labels_heard));
   SE2_THREAD_CHECK_OOM(global_labels_heard);
   IGRAPH_FINALLY(igraph_free, global_labels_heard);
 
@@ -153,23 +150,21 @@ igraph_error_t se2_partition_init(se2_partition* partition,
   SE2_THREAD_CHECK(igraph_matrix_init(local_labels_heard, n_nodes,
                                       partition->max_label + 1));
   IGRAPH_FINALLY(igraph_matrix_destroy, local_labels_heard);
-  SE2_THREAD_CHECK(igraph_vector_init(global_labels_heard,
-                                      partition->max_label + 1));
+  SE2_THREAD_CHECK(
+    igraph_vector_init(global_labels_heard, partition->max_label + 1));
   IGRAPH_FINALLY(igraph_vector_destroy, global_labels_heard);
 
   SE2_THREAD_CHECK(se2_count_local_labels(
-                     graph, initial_labels,
-                     partition->max_label, local_labels_heard));
+                     graph, initial_labels, partition->max_label, local_labels_heard));
   SE2_THREAD_CHECK(se2_count_global_labels(
-                     graph, partition->max_label,
-                     local_labels_heard, global_labels_heard));
+                     graph, partition->max_label, local_labels_heard, global_labels_heard));
 
   IGRAPH_FINALLY_CLEAN(12);
 
   return IGRAPH_SUCCESS;
 }
 
-void se2_partition_destroy(se2_partition* partition)
+void se2_partition_destroy(se2_partition *partition)
 {
   igraph_vector_int_destroy(partition->reference);
   igraph_vector_int_destroy(partition->stage);
@@ -186,22 +181,21 @@ void se2_partition_destroy(se2_partition* partition)
   igraph_free(partition->global_labels_heard);
 }
 
-void se2_iterator_shuffle(se2_iterator* iterator)
+void se2_iterator_shuffle(se2_iterator *iterator)
 {
   iterator->pos = 0;
-  se2_randperm(iterator->ids, iterator->n_total,
-               iterator->n_iter);
+  se2_randperm(iterator->ids, iterator->n_total, iterator->n_iter);
 }
 
-void se2_iterator_reset(se2_iterator* iterator)
+void se2_iterator_reset(se2_iterator *iterator)
 {
   iterator->pos = 0;
 }
 
 // WARNING: Iterator does not take ownership of the id vector so it must still
 // be cleaned up by the caller.
-igraph_error_t se2_iterator_from_vector(se2_iterator* iterator,
-                                        igraph_vector_int_t* ids,
+igraph_error_t se2_iterator_from_vector(se2_iterator *iterator,
+                                        igraph_vector_int_t *ids,
                                         igraph_integer_t const n_iter)
 {
   igraph_integer_t const n = igraph_vector_int_size(ids);
@@ -214,24 +208,24 @@ igraph_error_t se2_iterator_from_vector(se2_iterator* iterator,
   return IGRAPH_SUCCESS;
 }
 
-igraph_error_t se2_iterator_random_node_init(se2_iterator* iterator,
-    se2_partition const* partition,
+igraph_error_t se2_iterator_random_node_init(se2_iterator *iterator,
+    se2_partition const *partition,
     igraph_real_t const proportion)
 {
   igraph_integer_t n_total = partition->n_nodes;
   igraph_integer_t n_iter = n_total;
-  igraph_vector_int_t* nodes = igraph_malloc(sizeof(* nodes));
+  igraph_vector_int_t *nodes = igraph_malloc(sizeof(*nodes));
   SE2_THREAD_CHECK_OOM(nodes);
   IGRAPH_FINALLY(igraph_free, nodes);
 
   SE2_THREAD_CHECK(igraph_vector_int_init(nodes, n_total));
   IGRAPH_FINALLY(igraph_vector_int_destroy, nodes);
   for (igraph_integer_t i = 0; i < n_total; i++) {
-    VECTOR(* nodes)[i] = i;
+    VECTOR(*nodes)[i] = i;
   }
 
   if (proportion) {
-    n_iter = n_total* proportion;
+    n_iter = n_total *proportion;
   }
 
   se2_iterator_from_vector(iterator, nodes, n_iter);
@@ -244,27 +238,27 @@ igraph_error_t se2_iterator_random_node_init(se2_iterator* iterator,
   return IGRAPH_SUCCESS;
 }
 
-igraph_error_t se2_iterator_random_label_init(se2_iterator* iterator,
-    se2_partition const* partition,
+igraph_error_t se2_iterator_random_label_init(se2_iterator *iterator,
+    se2_partition const *partition,
     igraph_real_t const proportion)
 {
   igraph_integer_t n_total = partition->n_labels;
   igraph_integer_t n_iter = n_total;
-  igraph_vector_int_t* labels = igraph_malloc(sizeof(* labels));
+  igraph_vector_int_t *labels = igraph_malloc(sizeof(*labels));
   SE2_THREAD_CHECK_OOM(labels);
   IGRAPH_FINALLY(igraph_free, labels);
 
   SE2_THREAD_CHECK(igraph_vector_int_init(labels, n_total));
   IGRAPH_FINALLY(igraph_vector_int_destroy, labels);
   for (igraph_integer_t i = 0, j = 0; i < n_total; j++) {
-    if (VECTOR(* (partition->community_sizes))[j] > 0) {
-      VECTOR(* labels)[i] = j;
+    if (VECTOR(*(partition->community_sizes))[j] > 0) {
+      VECTOR(*labels)[i] = j;
       i++;
     }
   }
 
   if (proportion) {
-    n_iter = n_total* proportion;
+    n_iter = n_total *proportion;
   }
 
   se2_iterator_from_vector(iterator, labels, n_iter);
@@ -277,10 +271,11 @@ igraph_error_t se2_iterator_random_label_init(se2_iterator* iterator,
   return IGRAPH_SUCCESS;
 }
 
-igraph_error_t se2_iterator_k_worst_fit_nodes_init(se2_iterator* iterator,
-    se2_partition const* partition, igraph_integer_t const k)
+igraph_error_t se2_iterator_k_worst_fit_nodes_init(se2_iterator *iterator,
+    se2_partition const *partition,
+    igraph_integer_t const k)
 {
-  igraph_vector_int_t* ids = igraph_malloc(sizeof(* ids));
+  igraph_vector_int_t *ids = igraph_malloc(sizeof(*ids));
   SE2_THREAD_CHECK_OOM(ids);
   IGRAPH_FINALLY(igraph_free, ids);
 
@@ -302,7 +297,7 @@ igraph_error_t se2_iterator_k_worst_fit_nodes_init(se2_iterator* iterator,
   return IGRAPH_SUCCESS;
 }
 
-void se2_iterator_destroy(se2_iterator* iterator)
+void se2_iterator_destroy(se2_iterator *iterator)
 {
   if (iterator->owns_ids) {
     igraph_vector_int_destroy(iterator->ids);
@@ -310,7 +305,7 @@ void se2_iterator_destroy(se2_iterator* iterator)
   }
 }
 
-igraph_integer_t se2_iterator_next(se2_iterator* iterator)
+igraph_integer_t se2_iterator_next(se2_iterator *iterator)
 {
   igraph_integer_t n = 0;
   if (iterator->pos == iterator->n_iter) {
@@ -318,50 +313,52 @@ igraph_integer_t se2_iterator_next(se2_iterator* iterator)
     return -1;
   }
 
-  n = VECTOR(* iterator->ids)[iterator->pos];
+  n = VECTOR(*iterator->ids)[iterator->pos];
   iterator->pos++;
 
   return n;
 }
 
-igraph_integer_t se2_partition_n_nodes(se2_partition const* partition)
+igraph_integer_t se2_partition_n_nodes(se2_partition const *partition)
 {
   return partition->n_nodes;
 }
 
-igraph_integer_t se2_partition_n_labels(se2_partition const* partition)
+igraph_integer_t se2_partition_n_labels(se2_partition const *partition)
 {
   return partition->n_labels;
 }
 
-igraph_integer_t se2_partition_max_label(se2_partition const* partition)
+igraph_integer_t se2_partition_max_label(se2_partition const *partition)
 {
   return partition->max_label;
 }
 
-void se2_partition_add_to_stage(se2_partition* partition,
+void se2_partition_add_to_stage(se2_partition *partition,
                                 igraph_integer_t const node_id,
                                 igraph_integer_t const label,
                                 igraph_real_t specificity)
 {
-  VECTOR(* partition->stage)[node_id] = label;
-  VECTOR(* partition->label_quality)[node_id] = specificity;
+  VECTOR(*partition->stage)[node_id] = label;
+  VECTOR(*partition->label_quality)[node_id] = specificity;
 }
 
 // Return an unused label.
-igraph_integer_t se2_partition_new_label(se2_partition* partition)
+igraph_integer_t se2_partition_new_label(se2_partition *partition)
 {
-  igraph_integer_t pool_size = igraph_vector_int_size(
-                                 partition->community_sizes);
+  igraph_integer_t pool_size =
+    igraph_vector_int_size(partition->community_sizes);
   igraph_integer_t next_label = 0;
   while ((next_label < pool_size) &&
-         (VECTOR(* partition->community_sizes)[next_label])) {
+         (VECTOR(*partition->community_sizes)[next_label])) {
     next_label++;
   }
 
   if (next_label == igraph_vector_int_capacity(partition->community_sizes)) {
-    SE2_THREAD_CHECK_RETURN(igraph_vector_int_reserve(partition->community_sizes,
-                            MAX(2 * pool_size, partition->n_nodes)), -1);
+    SE2_THREAD_CHECK_RETURN(
+      igraph_vector_int_reserve(partition->community_sizes,
+                                MAX(2 * pool_size, partition->n_nodes)),
+      -1);
   }
 
   if (next_label == pool_size) {
@@ -376,17 +373,17 @@ igraph_integer_t se2_partition_new_label(se2_partition* partition)
   partition->n_labels++;
 
   // Mark new label as reserved.
-  VECTOR(* partition->community_sizes)[next_label] = -1;
+  VECTOR(*partition->community_sizes)[next_label] = -1;
 
   return next_label;
 }
 
-static inline void se2_partition_free_label(se2_partition* partition,
+static inline void se2_partition_free_label(se2_partition *partition,
     igraph_integer_t const label)
 {
-  VECTOR(* partition->community_sizes)[label] = 0;
+  VECTOR(*partition->community_sizes)[label] = 0;
   if (label == partition->max_label) {
-    while ((!VECTOR(* partition->community_sizes)[partition->max_label]) &&
+    while ((!VECTOR(*partition->community_sizes)[partition->max_label]) &&
            (partition->max_label > 0)) {
       partition->max_label--;
     }
@@ -395,61 +392,61 @@ static inline void se2_partition_free_label(se2_partition* partition,
   partition->n_labels--;
 }
 
-igraph_integer_t se2_partition_community_size(se2_partition const* partition,
+igraph_integer_t se2_partition_community_size(se2_partition const *partition,
     igraph_integer_t const label)
 {
-  return VECTOR(* partition->community_sizes)[label];
+  return VECTOR(*partition->community_sizes)[label];
 }
 
-igraph_real_t se2_vector_median(igraph_vector_t const* vec)
+igraph_real_t se2_vector_median(igraph_vector_t const *vec)
 {
   igraph_vector_int_t ids;
   igraph_integer_t len = igraph_vector_size(vec) - 1;
   igraph_integer_t k = len / 2;
   igraph_real_t res;
 
-  SE2_THREAD_CHECK_RETURN(igraph_vector_int_init( &ids, len), 0);
+  SE2_THREAD_CHECK_RETURN(igraph_vector_int_init(&ids, len), 0);
   IGRAPH_FINALLY(igraph_vector_int_destroy, &ids);
   SE2_THREAD_CHECK_RETURN(igraph_vector_qsort_ind(vec, &ids, IGRAPH_ASCENDING),
                           0);
-  res = VECTOR(* vec)[VECTOR(ids)[k]];
+  res = VECTOR(*vec)[VECTOR(ids)[k]];
 
   if (len % 2) {
-    res += VECTOR(* vec)[VECTOR(ids)[k + 1]];
+    res += VECTOR(*vec)[VECTOR(ids)[k + 1]];
     res /= 2;
   }
 
-  igraph_vector_int_destroy( &ids);
+  igraph_vector_int_destroy(&ids);
   IGRAPH_FINALLY_CLEAN(1);
 
   return res;
 }
-igraph_real_t se2_vector_int_median(igraph_vector_int_t const* vec)
+igraph_real_t se2_vector_int_median(igraph_vector_int_t const *vec)
 {
   igraph_vector_int_t ids;
   igraph_integer_t len = igraph_vector_int_size(vec) - 1;
   igraph_integer_t k = len / 2;
   igraph_real_t res;
 
-  SE2_THREAD_CHECK_RETURN(igraph_vector_int_init( &ids, len), 0);
+  SE2_THREAD_CHECK_RETURN(igraph_vector_int_init(&ids, len), 0);
   IGRAPH_FINALLY(igraph_vector_int_destroy, &ids);
   SE2_THREAD_CHECK_RETURN(
     igraph_vector_int_qsort_ind(vec, &ids, IGRAPH_ASCENDING), 0);
-  res = VECTOR(* vec)[VECTOR(ids)[k]];
+  res = VECTOR(*vec)[VECTOR(ids)[k]];
 
   if (len % 2) {
-    res += VECTOR(* vec)[VECTOR(ids)[k + 1]];
+    res += VECTOR(*vec)[VECTOR(ids)[k + 1]];
     res /= 2;
   }
 
-  igraph_vector_int_destroy( &ids);
+  igraph_vector_int_destroy(&ids);
   IGRAPH_FINALLY_CLEAN(1);
 
   return res;
 }
 
-igraph_integer_t se2_partition_median_community_size(
-  se2_partition const* partition)
+igraph_integer_t se2_partition_median_community_size(se2_partition const
+    *partition)
 {
   if (partition->n_labels == 1) {
     return partition->n_nodes;
@@ -460,32 +457,32 @@ igraph_integer_t se2_partition_median_community_size(
   igraph_integer_t res = 0;
 
   SE2_THREAD_CHECK_RETURN(
-    se2_iterator_random_label_init( &label_iter, partition, 0), 0);
+    se2_iterator_random_label_init(&label_iter, partition, 0), 0);
   IGRAPH_FINALLY(se2_iterator_destroy, &label_iter);
   SE2_THREAD_CHECK_RETURN(
-    igraph_vector_int_init( &community_sizes, partition->n_labels), 0);
+    igraph_vector_int_init(&community_sizes, partition->n_labels), 0);
   IGRAPH_FINALLY(igraph_vector_int_destroy, &community_sizes);
 
   igraph_integer_t label_id;
   igraph_integer_t label_i = 0;
-  while ((label_id = se2_iterator_next( &label_iter)) != -1) {
-    VECTOR(community_sizes)[label_i] =
-      se2_partition_community_size(partition, label_id);
+  while ((label_id = se2_iterator_next(&label_iter)) != -1) {
+    VECTOR(community_sizes)
+    [label_i] = se2_partition_community_size(partition, label_id);
     label_i++;
   }
-  SE2_THREAD_CHECK_RETURN(
-    igraph_vector_int_resize( &community_sizes, label_i), 0);
+  SE2_THREAD_CHECK_RETURN(igraph_vector_int_resize(&community_sizes, label_i),
+                          0);
 
-  res = se2_vector_int_median( &community_sizes);
+  res = se2_vector_int_median(&community_sizes);
 
-  se2_iterator_destroy( &label_iter);
-  igraph_vector_int_destroy( &community_sizes);
+  se2_iterator_destroy(&label_iter);
+  igraph_vector_int_destroy(&community_sizes);
   IGRAPH_FINALLY_CLEAN(2);
 
   return res;
 }
 
-void se2_partition_merge_labels(se2_partition* partition, igraph_integer_t c1,
+void se2_partition_merge_labels(se2_partition *partition, igraph_integer_t c1,
                                 igraph_integer_t c2)
 {
   // Ensure smaller community engulfed by larger community. Not necessary.
@@ -497,8 +494,8 @@ void se2_partition_merge_labels(se2_partition* partition, igraph_integer_t c1,
   }
 
   for (igraph_integer_t i = 0; i < partition->n_nodes; i++) {
-    if (LABEL(* partition)[i] == c2) {
-      STAGE(* partition)[i] = c1;
+    if (LABEL(*partition)[i] == c2) {
+      STAGE(*partition)[i] = c1;
     }
   }
 
@@ -506,14 +503,14 @@ void se2_partition_merge_labels(se2_partition* partition, igraph_integer_t c1,
 }
 
 // Move nodes in mask to new label.
-igraph_error_t se2_partition_relabel_mask(se2_partition* partition,
-    igraph_vector_bool_t const* mask)
+igraph_error_t se2_partition_relabel_mask(se2_partition *partition,
+    igraph_vector_bool_t const *mask)
 {
   igraph_integer_t label = se2_partition_new_label(partition);
   SE2_THREAD_STATUS();
   for (igraph_integer_t i = 0; i < partition->n_nodes; i++) {
-    if (VECTOR(* mask)[i]) {
-      VECTOR(* partition->stage)[i] = label;
+    if (VECTOR(*mask)[i]) {
+      VECTOR(*partition->stage)[i] = label;
     }
   }
 
@@ -521,21 +518,21 @@ igraph_error_t se2_partition_relabel_mask(se2_partition* partition,
 }
 
 static igraph_error_t se2_partition_recount_community_sizes(
-  se2_partition* partition)
+  se2_partition *partition)
 {
-  partition->n_labels = se2_count_labels(partition->stage,
-                                         partition->community_sizes);
+  partition->n_labels =
+    se2_count_labels(partition->stage, partition->community_sizes);
   SE2_THREAD_STATUS();
-  partition->max_label =
-    igraph_vector_int_size(partition->community_sizes) - 1;
+  partition->max_label = igraph_vector_int_size(partition->community_sizes) - 1;
 
   return IGRAPH_SUCCESS;
 }
 
-static igraph_error_t se2_resize_local_labels(se2_partition* partition,
-    igraph_integer_t const n_nodes, igraph_integer_t n_labels)
+static igraph_error_t se2_resize_local_labels(se2_partition *partition,
+    igraph_integer_t const n_nodes,
+    igraph_integer_t n_labels)
 {
-  igraph_matrix_t* new_local_labels = igraph_malloc(sizeof(* new_local_labels));
+  igraph_matrix_t *new_local_labels = igraph_malloc(sizeof(*new_local_labels));
   SE2_THREAD_CHECK_OOM(new_local_labels);
   IGRAPH_FINALLY(igraph_free, new_local_labels);
 
@@ -548,8 +545,8 @@ static igraph_error_t se2_resize_local_labels(se2_partition* partition,
     igraph_matrix_ncol(partition->local_labels_heard);
   for (igraph_integer_t i = 0; i < old_n_nodes; i++) {
     for (igraph_integer_t j = 0; j < old_n_labels; j++) {
-      MATRIX(* new_local_labels, i, j) =
-        MATRIX(* partition->local_labels_heard, i, j);
+      MATRIX(*new_local_labels, i, j) =
+        MATRIX(*partition->local_labels_heard, i, j);
     }
   }
 
@@ -564,73 +561,73 @@ static igraph_error_t se2_resize_local_labels(se2_partition* partition,
 
 /* For each node that switched labels, move their edge weights from the old
    label to the new label. */
-static igraph_error_t se2_move_labels_heard(se2_partition* partition,
-    se2_neighs const* graph)
+static igraph_error_t se2_move_labels_heard(se2_partition *partition,
+    se2_neighs const *graph)
 {
-  igraph_integer_t old_max_label = igraph_vector_size(
-                                     partition->global_labels_heard) - 1;
+  igraph_integer_t old_max_label =
+    igraph_vector_size(partition->global_labels_heard) - 1;
   if (old_max_label < partition->max_label) {
     igraph_integer_t n_labels = partition->max_label + 1;
 
-    SE2_THREAD_CHECK(igraph_vector_resize(
-                       partition->global_labels_heard, n_labels));
+    SE2_THREAD_CHECK(
+      igraph_vector_resize(partition->global_labels_heard, n_labels));
     for (igraph_integer_t i = old_max_label + 1; i < n_labels; i++) {
-      VECTOR(* partition->global_labels_heard)[i] = 0;
+      VECTOR(*partition->global_labels_heard)[i] = 0;
     }
 
-    SE2_THREAD_CHECK(se2_resize_local_labels(partition, partition->n_nodes,
-                     n_labels));
+    SE2_THREAD_CHECK(
+      se2_resize_local_labels(partition, partition->n_nodes, n_labels));
     for (igraph_integer_t i = 0; i < partition->n_nodes; i++) {
       for (igraph_integer_t j = old_max_label + 1; j < n_labels; j++) {
-        MATRIX(* partition->local_labels_heard, i, j) = 0;
+        MATRIX(*partition->local_labels_heard, i, j) = 0;
       }
     }
   }
 
   for (igraph_integer_t node_id = 0; node_id < partition->n_nodes; node_id++) {
-    if (LABEL(* partition)[node_id] == STAGE(* partition)[node_id]) {
+    if (LABEL(*partition)[node_id] == STAGE(*partition)[node_id]) {
       continue;
     }
 
-    igraph_integer_t const old_label = LABEL(* partition)[node_id];
-    igraph_integer_t const new_label = STAGE(* partition)[node_id];
+    igraph_integer_t const old_label = LABEL(*partition)[node_id];
+    igraph_integer_t const new_label = STAGE(*partition)[node_id];
 
     igraph_real_t acc = 0;
-    for (igraph_integer_t j = 0; j < N_NEIGHBORS(* graph, node_id); j++) {
-      acc += WEIGHT(* graph, node_id, j);
+    for (igraph_integer_t j = 0; j < N_NEIGHBORS(*graph, node_id); j++) {
+      acc += WEIGHT(*graph, node_id, j);
     }
 
-    VECTOR(* partition->global_labels_heard)[old_label] -= acc;
-    VECTOR(* partition->global_labels_heard)[new_label] += acc;
+    VECTOR(*partition->global_labels_heard)[old_label] -= acc;
+    VECTOR(*partition->global_labels_heard)[new_label] += acc;
 
-    for (igraph_integer_t j = 0; j < N_NEIGHBORS(* graph, node_id); j++) {
-      MATRIX(* partition->local_labels_heard, NEIGHBOR(* graph, node_id, j),
-             old_label) -= WEIGHT(* graph, node_id, j);
-      MATRIX(* partition->local_labels_heard, NEIGHBOR(* graph, node_id, j),
-             new_label) += WEIGHT(* graph, node_id, j);
+    for (igraph_integer_t j = 0; j < N_NEIGHBORS(*graph, node_id); j++) {
+      MATRIX(*partition->local_labels_heard, NEIGHBOR(*graph, node_id, j),
+             old_label) -= WEIGHT(*graph, node_id, j);
+      MATRIX(*partition->local_labels_heard, NEIGHBOR(*graph, node_id, j),
+             new_label) += WEIGHT(*graph, node_id, j);
     }
   }
 
   return IGRAPH_SUCCESS;
 }
 
-igraph_error_t se2_partition_commit_changes(se2_partition* partition,
-    se2_neighs const* graph)
+igraph_error_t se2_partition_commit_changes(se2_partition *partition,
+    se2_neighs const *graph)
 {
   SE2_THREAD_CHECK(se2_partition_recount_community_sizes(partition));
   SE2_THREAD_CHECK(se2_move_labels_heard(partition, graph));
-  SE2_THREAD_CHECK(igraph_vector_int_update(partition->reference,
-                   partition->stage));
+  SE2_THREAD_CHECK(
+    igraph_vector_int_update(partition->reference, partition->stage));
 
   return IGRAPH_SUCCESS;
 }
 
-static igraph_error_t se2_reindex_membership(igraph_vector_int_t* membership)
+static igraph_error_t se2_reindex_membership(igraph_vector_int_t *membership)
 {
   igraph_vector_int_t indices;
   igraph_integer_t n_nodes = igraph_vector_int_size(membership);
 
-  SE2_THREAD_CHECK(igraph_vector_int_init( &indices, n_nodes));
+  SE2_THREAD_CHECK(igraph_vector_int_init(&indices, n_nodes));
   IGRAPH_FINALLY(igraph_vector_int_destroy, &indices);
 
   SE2_THREAD_CHECK(
@@ -638,15 +635,15 @@ static igraph_error_t se2_reindex_membership(igraph_vector_int_t* membership)
 
   igraph_integer_t c_old, c_new = -1, c_prev_node = -1;
   for (igraph_integer_t i = 0; i < n_nodes; i++) {
-    c_old = VECTOR(* membership)[VECTOR(indices)[i]];
+    c_old = VECTOR(*membership)[VECTOR(indices)[i]];
     if (c_old != c_prev_node) {
       c_new++;
       c_prev_node = c_old;
     }
-    VECTOR(* membership)[VECTOR(indices)[i]] = c_new;
+    VECTOR(*membership)[VECTOR(indices)[i]] = c_new;
   }
 
-  igraph_vector_int_destroy( &indices);
+  igraph_vector_int_destroy(&indices);
   IGRAPH_FINALLY_CLEAN(1);
 
   return IGRAPH_SUCCESS;
@@ -658,11 +655,11 @@ partition store.
 NOTE: This saves only the membership ids for each node so it goes from a
 se2_partition to an igraph vector despite both arguments being
 "partitions". */
-igraph_error_t se2_partition_store(se2_partition const* working_partition,
-                                   igraph_vector_int_list_t* partition_store,
+igraph_error_t se2_partition_store(se2_partition const *working_partition,
+                                   igraph_vector_int_list_t *partition_store,
                                    igraph_integer_t const idx)
 {
-  igraph_vector_int_t* partition_state =
+  igraph_vector_int_t *partition_state =
     igraph_vector_int_list_get_ptr(partition_store, idx);
 
   SE2_THREAD_CHECK(
